/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 57 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 85 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 108 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 111 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 114 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractlight.sip"
#include <qabstractlight.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractraycaster.sip"
#include <qabstractraycaster.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttexture.sip"
#include <qabstracttexture.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstracttextureimage.sip"
#include <qabstracttextureimage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphacoverage.sip"
#include <qalphacoverage.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qalphatest.sip"
#include <qalphatest.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qattribute.sip"
#include <qattribute.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequation.sip"
#include <qblendequation.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblendequationarguments.sip"
#include <qblendequationarguments.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qblitframebuffer.sip"
#include <qblitframebuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbuffer.sip"
#include <qbuffer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qbufferdatagenerator.sip"
#include <qbufferdatagenerator.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcamera.sip"
#include <qcamera.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qcameralens.sip"
#include <qcameralens.h>
#line 147 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 150 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeleton.sip"
#include <qskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeletonloader.sip"
#include <qskeletonloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyupdatedchangebase.sip"
#include <qstaticpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyvalueaddedchangebase.sip"
#include <qstaticpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyvalueremovedchangebase.sip"
#include <qstaticpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qtransform.sip"
#include <qtransform.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qtransform.sip"
#include <qtransform.h>
#line 215 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 230 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 233 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 236 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 265 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 268 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 271 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 274 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 327 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 330 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 333 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 368 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 373 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 376 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 379 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 382 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 385 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 388 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 391 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 394 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 397 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 400 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 403 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 406 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 409 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 412 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQCamera.cpp"


class sipQt3DRender_QCamera : public ::Qt3DRender::QCamera
{
public:
    sipQt3DRender_QCamera(::Qt3DCore::QNode*);
    virtual ~sipQt3DRender_QCamera();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DRender_QCamera(const sipQt3DRender_QCamera &);
    sipQt3DRender_QCamera &operator = (const sipQt3DRender_QCamera &);

    char sipPyMethods[8];
};

sipQt3DRender_QCamera::sipQt3DRender_QCamera(::Qt3DCore::QNode*a0): ::Qt3DRender::QCamera(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QCamera::~sipQt3DRender_QCamera()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQt3DRender_QCamera::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_Qt3DRender_qt_metaobject(sipPySelf, sipType_Qt3DRender_QCamera);

    return ::Qt3DRender::QCamera::metaObject();
}

int sipQt3DRender_QCamera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Qt3DRender::QCamera::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_Qt3DRender_qt_metacall(sipPySelf, sipType_Qt3DRender_QCamera, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQt3DRender_QCamera::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_Qt3DRender_qt_metacast(sipPySelf, sipType_Qt3DRender_QCamera, _clname, &sipCpp) ? sipCpp : ::Qt3DRender::QCamera::qt_metacast(_clname));
}

void sipQt3DRender_QCamera::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QCamera::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DRender_7(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QCamera::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Qt3DRender::QCamera::event(a0);

    extern bool sipVH_Qt3DRender_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_Qt3DRender_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQt3DRender_QCamera::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Qt3DRender::QCamera::eventFilter(a0, a1);

    extern bool sipVH_Qt3DRender_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_Qt3DRender_5(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQt3DRender_QCamera::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QCamera::timerEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_Qt3DRender_4(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QCamera::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QCamera::childEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_Qt3DRender_3(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QCamera::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Qt3DRender::QCamera::customEvent(a0);
        return;
    }

    extern void sipVH_Qt3DRender_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_Qt3DRender_2(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QCamera::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QCamera::connectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQt3DRender_QCamera::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Qt3DRender::QCamera::disconnectNotify(a0);
        return;
    }

    extern void sipVH_Qt3DRender_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_Qt3DRender_1(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_lens, "lens(self) -> QCameraLens|None");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_lens(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_lens(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            ::Qt3DRender::QCameraLens*sipRes;

            sipRes = sipCpp->lens();

            return sipConvertFromType(sipRes, sipType_Qt3DRender_QCameraLens, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_lens, doc_Qt3DRender_QCamera_lens);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_transform, "transform(self) -> QTransform|None");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_transform(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_transform(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            ::Qt3DCore::QTransform*sipRes;

            sipRes = sipCpp->transform();

            return sipConvertFromType(sipRes, sipType_Qt3DCore_QTransform, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_transform, doc_Qt3DRender_QCamera_transform);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_tiltRotation, "tiltRotation(self, angle: float) -> QQuaternion");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_tiltRotation(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_tiltRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            ::QQuaternion*sipRes;

            sipRes = new ::QQuaternion(sipCpp->tiltRotation(a0));

            return sipConvertFromNewType(sipRes, sipType_QQuaternion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_tiltRotation, doc_Qt3DRender_QCamera_tiltRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_panRotation, "panRotation(self, angle: float) -> QQuaternion");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_panRotation(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_panRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            ::QQuaternion*sipRes;

            sipRes = new ::QQuaternion(sipCpp->panRotation(a0));

            return sipConvertFromNewType(sipRes, sipType_QQuaternion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_panRotation, doc_Qt3DRender_QCamera_panRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_rollRotation, "rollRotation(self, angle: float) -> QQuaternion");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_rollRotation(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_rollRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            ::QQuaternion*sipRes;

            sipRes = new ::QQuaternion(sipCpp->rollRotation(a0));

            return sipConvertFromNewType(sipRes, sipType_QQuaternion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_rollRotation, doc_Qt3DRender_QCamera_rollRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_rotation, "rotation(self, angle: float, axis: QVector3D) -> QQuaternion");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_rotation(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        const ::QVector3D* a1;
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BfJ9", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0, sipType_QVector3D, &a1))
        {
            ::QQuaternion*sipRes;

            sipRes = new ::QQuaternion(sipCpp->rotation(a0, *a1));

            return sipConvertFromNewType(sipRes, sipType_QQuaternion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_rotation, doc_Qt3DRender_QCamera_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_translate, "translate(self, vLocal: QVector3D, option: QCamera.CameraTranslationOption = Qt3DRender.QCamera.TranslateViewCenter)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_translate(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_translate(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::Qt3DRender::QCamera::CameraTranslationOption a1 = Qt3DRender::QCamera::TranslateViewCenter;
        ::Qt3DRender::QCamera *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|E", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_QVector3D, &a0, sipType_Qt3DRender_QCamera_CameraTranslationOption, &a1))
        {
            sipCpp->translate(*a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_translate, doc_Qt3DRender_QCamera_translate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_translateWorld, "translateWorld(self, vWorld: QVector3D, option: QCamera.CameraTranslationOption = Qt3DRender.QCamera.TranslateViewCenter)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_translateWorld(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_translateWorld(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::Qt3DRender::QCamera::CameraTranslationOption a1 = Qt3DRender::QCamera::TranslateViewCenter;
        ::Qt3DRender::QCamera *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|E", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_QVector3D, &a0, sipType_Qt3DRender_QCamera_CameraTranslationOption, &a1))
        {
            sipCpp->translateWorld(*a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_translateWorld, doc_Qt3DRender_QCamera_translateWorld);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_tilt, "tilt(self, angle: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_tilt(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_tilt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->tilt(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_tilt, doc_Qt3DRender_QCamera_tilt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_pan, "pan(self, angle: float)\n"
"pan(self, angle: float, axis: QVector3D)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_pan(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_pan(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->pan(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        float a0;
        const ::QVector3D* a1;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BfJ9", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0, sipType_QVector3D, &a1))
        {
            sipCpp->pan(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_pan, doc_Qt3DRender_QCamera_pan);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_roll, "roll(self, angle: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_roll(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_roll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->roll(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_roll, doc_Qt3DRender_QCamera_roll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_tiltAboutViewCenter, "tiltAboutViewCenter(self, angle: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_tiltAboutViewCenter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_tiltAboutViewCenter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->tiltAboutViewCenter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_tiltAboutViewCenter, doc_Qt3DRender_QCamera_tiltAboutViewCenter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_panAboutViewCenter, "panAboutViewCenter(self, angle: float)\n"
"panAboutViewCenter(self, angle: float, axis: QVector3D)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_panAboutViewCenter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_panAboutViewCenter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->panAboutViewCenter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        float a0;
        const ::QVector3D* a1;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BfJ9", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0, sipType_QVector3D, &a1))
        {
            sipCpp->panAboutViewCenter(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_panAboutViewCenter, doc_Qt3DRender_QCamera_panAboutViewCenter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_rollAboutViewCenter, "rollAboutViewCenter(self, angle: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_rollAboutViewCenter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_rollAboutViewCenter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->rollAboutViewCenter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_rollAboutViewCenter, doc_Qt3DRender_QCamera_rollAboutViewCenter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_rotate, "rotate(self, q: QQuaternion)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_rotate(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_rotate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuaternion* a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_QQuaternion, &a0))
        {
            sipCpp->rotate(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_rotate, doc_Qt3DRender_QCamera_rotate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_rotateAboutViewCenter, "rotateAboutViewCenter(self, q: QQuaternion)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_rotateAboutViewCenter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_rotateAboutViewCenter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuaternion* a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_QQuaternion, &a0))
        {
            sipCpp->rotateAboutViewCenter(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_rotateAboutViewCenter, doc_Qt3DRender_QCamera_rotateAboutViewCenter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_projectionType, "projectionType(self) -> QCameraLens.ProjectionType");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_projectionType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_projectionType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            ::Qt3DRender::QCameraLens::ProjectionType sipRes;

            sipRes = sipCpp->projectionType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DRender_QCameraLens_ProjectionType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_projectionType, doc_Qt3DRender_QCamera_projectionType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_nearPlane, "nearPlane(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_nearPlane(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_nearPlane(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->nearPlane();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_nearPlane, doc_Qt3DRender_QCamera_nearPlane);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_farPlane, "farPlane(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_farPlane(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_farPlane(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->farPlane();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_farPlane, doc_Qt3DRender_QCamera_farPlane);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_fieldOfView, "fieldOfView(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_fieldOfView(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_fieldOfView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->fieldOfView();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_fieldOfView, doc_Qt3DRender_QCamera_fieldOfView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_aspectRatio, "aspectRatio(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_aspectRatio(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_aspectRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->aspectRatio();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_aspectRatio, doc_Qt3DRender_QCamera_aspectRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_left, "left(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_left(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_left(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->left();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_left, doc_Qt3DRender_QCamera_left);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_right, "right(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_right(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_right(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->right();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_right, doc_Qt3DRender_QCamera_right);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_bottom, "bottom(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_bottom(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_bottom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->bottom();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_bottom, doc_Qt3DRender_QCamera_bottom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_top, "top(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_top(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_top(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->top();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_top, doc_Qt3DRender_QCamera_top);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_projectionMatrix, "projectionMatrix(self) -> QMatrix4x4");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_projectionMatrix(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_projectionMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            ::QMatrix4x4*sipRes;

            sipRes = new ::QMatrix4x4(sipCpp->projectionMatrix());

            return sipConvertFromNewType(sipRes, sipType_QMatrix4x4, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_projectionMatrix, doc_Qt3DRender_QCamera_projectionMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_position, "position(self) -> QVector3D");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_position(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->position());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_position, doc_Qt3DRender_QCamera_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_upVector, "upVector(self) -> QVector3D");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_upVector(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_upVector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->upVector());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_upVector, doc_Qt3DRender_QCamera_upVector);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_viewCenter, "viewCenter(self) -> QVector3D");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_viewCenter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_viewCenter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->viewCenter());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_viewCenter, doc_Qt3DRender_QCamera_viewCenter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_viewVector, "viewVector(self) -> QVector3D");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_viewVector(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_viewVector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->viewVector());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_viewVector, doc_Qt3DRender_QCamera_viewVector);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_viewMatrix, "viewMatrix(self) -> QMatrix4x4");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_viewMatrix(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_viewMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            ::QMatrix4x4*sipRes;

            sipRes = new ::QMatrix4x4(sipCpp->viewMatrix());

            return sipConvertFromNewType(sipRes, sipType_QMatrix4x4, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_viewMatrix, doc_Qt3DRender_QCamera_viewMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setProjectionType, "setProjectionType(self, type: QCameraLens.ProjectionType)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setProjectionType(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setProjectionType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QCameraLens::ProjectionType a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_Qt3DRender_QCameraLens_ProjectionType, &a0))
        {
            sipCpp->setProjectionType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setProjectionType, doc_Qt3DRender_QCamera_setProjectionType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setNearPlane, "setNearPlane(self, nearPlane: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setNearPlane(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setNearPlane(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->setNearPlane(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setNearPlane, doc_Qt3DRender_QCamera_setNearPlane);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setFarPlane, "setFarPlane(self, farPlane: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setFarPlane(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setFarPlane(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->setFarPlane(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setFarPlane, doc_Qt3DRender_QCamera_setFarPlane);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setFieldOfView, "setFieldOfView(self, fieldOfView: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setFieldOfView(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setFieldOfView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->setFieldOfView(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setFieldOfView, doc_Qt3DRender_QCamera_setFieldOfView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setAspectRatio, "setAspectRatio(self, aspectRatio: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setAspectRatio(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setAspectRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->setAspectRatio(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setAspectRatio, doc_Qt3DRender_QCamera_setAspectRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setLeft, "setLeft(self, left: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setLeft(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setLeft(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->setLeft(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setLeft, doc_Qt3DRender_QCamera_setLeft);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setRight, "setRight(self, right: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setRight(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setRight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->setRight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setRight, doc_Qt3DRender_QCamera_setRight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setBottom, "setBottom(self, bottom: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setBottom(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setBottom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->setBottom(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setBottom, doc_Qt3DRender_QCamera_setBottom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setTop, "setTop(self, top: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setTop(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setTop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->setTop(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setTop, doc_Qt3DRender_QCamera_setTop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setProjectionMatrix, "setProjectionMatrix(self, projectionMatrix: QMatrix4x4)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setProjectionMatrix(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setProjectionMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMatrix4x4* a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_QMatrix4x4, &a0))
        {
            sipCpp->setProjectionMatrix(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setProjectionMatrix, doc_Qt3DRender_QCamera_setProjectionMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setPosition, "setPosition(self, position: QVector3D)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setPosition(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setPosition(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setPosition, doc_Qt3DRender_QCamera_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setUpVector, "setUpVector(self, upVector: QVector3D)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setUpVector(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setUpVector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setUpVector(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setUpVector, doc_Qt3DRender_QCamera_setUpVector);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setViewCenter, "setViewCenter(self, viewCenter: QVector3D)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setViewCenter(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setViewCenter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setViewCenter(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setViewCenter, doc_Qt3DRender_QCamera_setViewCenter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_exposure, "exposure(self) -> float");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_exposure(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_exposure(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->exposure();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_exposure, doc_Qt3DRender_QCamera_exposure);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_setExposure, "setExposure(self, exposure: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_setExposure(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_setExposure(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, &a0))
        {
            sipCpp->setExposure(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setExposure, doc_Qt3DRender_QCamera_setExposure);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_viewAll, "viewAll(self)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_viewAll(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_viewAll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp))
        {
            sipCpp->viewAll();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_viewAll, doc_Qt3DRender_QCamera_viewAll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_viewSphere, "viewSphere(self, center: QVector3D, radius: float)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_viewSphere(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_viewSphere(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        float a1;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9f", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_QVector3D, &a0, &a1))
        {
            sipCpp->viewSphere(*a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_viewSphere, doc_Qt3DRender_QCamera_viewSphere);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DRender_QCamera_viewEntity, "viewEntity(self, entity: QEntity|None)");

extern "C" {static PyObject *meth_Qt3DRender_QCamera_viewEntity(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QCamera_viewEntity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QEntity* a0;
        ::Qt3DRender::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_Qt3DRender_QCamera, &sipCpp, sipType_Qt3DCore_QEntity, &a0))
        {
            sipCpp->viewEntity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_viewEntity, doc_Qt3DRender_QCamera_viewEntity);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Qt3DRender_QCamera(void *, const sipTypeDef *);}
static void *cast_Qt3DRender_QCamera(void *sipCppV, const sipTypeDef *targetType)
{
    ::Qt3DRender::QCamera *sipCpp = reinterpret_cast< ::Qt3DRender::QCamera *>(sipCppV);

    if (targetType == sipType_Qt3DRender_QCamera)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_Qt3DCore_QEntity)->ctd_cast(static_cast< ::Qt3DCore::QEntity *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QCamera(void *, int);}
static void release_Qt3DRender_QCamera(void *sipCppV, int)
{
    ::Qt3DRender::QCamera *sipCpp = reinterpret_cast< ::Qt3DRender::QCamera *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Qt3DRender_QCamera(Py_ssize_t);}
static void *array_Qt3DRender_QCamera(Py_ssize_t sipNrElem)
{
    return new ::Qt3DRender::QCamera[sipNrElem];
}


extern "C" {static void array_delete_Qt3DRender_QCamera(void *);}
static void array_delete_Qt3DRender_QCamera(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DRender::QCamera *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DRender_QCamera(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QCamera(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DRender_QCamera *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QCamera(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DRender_QCamera(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QCamera(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQt3DRender_QCamera *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_Qt3DCore_QNode, &a0, sipOwner))
        {
            sipCpp = new sipQt3DRender_QCamera(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Qt3DRender_QCamera[] = {{3, 2, 1}};


static PyMethodDef methods_Qt3DRender_QCamera[] = {
    {sipName_aspectRatio, meth_Qt3DRender_QCamera_aspectRatio, METH_VARARGS, doc_Qt3DRender_QCamera_aspectRatio},
    {sipName_bottom, meth_Qt3DRender_QCamera_bottom, METH_VARARGS, doc_Qt3DRender_QCamera_bottom},
    {sipName_exposure, meth_Qt3DRender_QCamera_exposure, METH_VARARGS, doc_Qt3DRender_QCamera_exposure},
    {sipName_farPlane, meth_Qt3DRender_QCamera_farPlane, METH_VARARGS, doc_Qt3DRender_QCamera_farPlane},
    {sipName_fieldOfView, meth_Qt3DRender_QCamera_fieldOfView, METH_VARARGS, doc_Qt3DRender_QCamera_fieldOfView},
    {sipName_left, meth_Qt3DRender_QCamera_left, METH_VARARGS, doc_Qt3DRender_QCamera_left},
    {sipName_lens, meth_Qt3DRender_QCamera_lens, METH_VARARGS, doc_Qt3DRender_QCamera_lens},
    {sipName_nearPlane, meth_Qt3DRender_QCamera_nearPlane, METH_VARARGS, doc_Qt3DRender_QCamera_nearPlane},
    {sipName_pan, meth_Qt3DRender_QCamera_pan, METH_VARARGS, doc_Qt3DRender_QCamera_pan},
    {sipName_panAboutViewCenter, meth_Qt3DRender_QCamera_panAboutViewCenter, METH_VARARGS, doc_Qt3DRender_QCamera_panAboutViewCenter},
    {sipName_panRotation, meth_Qt3DRender_QCamera_panRotation, METH_VARARGS, doc_Qt3DRender_QCamera_panRotation},
    {sipName_position, meth_Qt3DRender_QCamera_position, METH_VARARGS, doc_Qt3DRender_QCamera_position},
    {sipName_projectionMatrix, meth_Qt3DRender_QCamera_projectionMatrix, METH_VARARGS, doc_Qt3DRender_QCamera_projectionMatrix},
    {sipName_projectionType, meth_Qt3DRender_QCamera_projectionType, METH_VARARGS, doc_Qt3DRender_QCamera_projectionType},
    {sipName_right, meth_Qt3DRender_QCamera_right, METH_VARARGS, doc_Qt3DRender_QCamera_right},
    {sipName_roll, meth_Qt3DRender_QCamera_roll, METH_VARARGS, doc_Qt3DRender_QCamera_roll},
    {sipName_rollAboutViewCenter, meth_Qt3DRender_QCamera_rollAboutViewCenter, METH_VARARGS, doc_Qt3DRender_QCamera_rollAboutViewCenter},
    {sipName_rollRotation, meth_Qt3DRender_QCamera_rollRotation, METH_VARARGS, doc_Qt3DRender_QCamera_rollRotation},
    {sipName_rotate, meth_Qt3DRender_QCamera_rotate, METH_VARARGS, doc_Qt3DRender_QCamera_rotate},
    {sipName_rotateAboutViewCenter, meth_Qt3DRender_QCamera_rotateAboutViewCenter, METH_VARARGS, doc_Qt3DRender_QCamera_rotateAboutViewCenter},
    {sipName_rotation, meth_Qt3DRender_QCamera_rotation, METH_VARARGS, doc_Qt3DRender_QCamera_rotation},
    {sipName_setAspectRatio, meth_Qt3DRender_QCamera_setAspectRatio, METH_VARARGS, doc_Qt3DRender_QCamera_setAspectRatio},
    {sipName_setBottom, meth_Qt3DRender_QCamera_setBottom, METH_VARARGS, doc_Qt3DRender_QCamera_setBottom},
    {sipName_setExposure, meth_Qt3DRender_QCamera_setExposure, METH_VARARGS, doc_Qt3DRender_QCamera_setExposure},
    {sipName_setFarPlane, meth_Qt3DRender_QCamera_setFarPlane, METH_VARARGS, doc_Qt3DRender_QCamera_setFarPlane},
    {sipName_setFieldOfView, meth_Qt3DRender_QCamera_setFieldOfView, METH_VARARGS, doc_Qt3DRender_QCamera_setFieldOfView},
    {sipName_setLeft, meth_Qt3DRender_QCamera_setLeft, METH_VARARGS, doc_Qt3DRender_QCamera_setLeft},
    {sipName_setNearPlane, meth_Qt3DRender_QCamera_setNearPlane, METH_VARARGS, doc_Qt3DRender_QCamera_setNearPlane},
    {sipName_setPosition, meth_Qt3DRender_QCamera_setPosition, METH_VARARGS, doc_Qt3DRender_QCamera_setPosition},
    {sipName_setProjectionMatrix, meth_Qt3DRender_QCamera_setProjectionMatrix, METH_VARARGS, doc_Qt3DRender_QCamera_setProjectionMatrix},
    {sipName_setProjectionType, meth_Qt3DRender_QCamera_setProjectionType, METH_VARARGS, doc_Qt3DRender_QCamera_setProjectionType},
    {sipName_setRight, meth_Qt3DRender_QCamera_setRight, METH_VARARGS, doc_Qt3DRender_QCamera_setRight},
    {sipName_setTop, meth_Qt3DRender_QCamera_setTop, METH_VARARGS, doc_Qt3DRender_QCamera_setTop},
    {sipName_setUpVector, meth_Qt3DRender_QCamera_setUpVector, METH_VARARGS, doc_Qt3DRender_QCamera_setUpVector},
    {sipName_setViewCenter, meth_Qt3DRender_QCamera_setViewCenter, METH_VARARGS, doc_Qt3DRender_QCamera_setViewCenter},
    {sipName_tilt, meth_Qt3DRender_QCamera_tilt, METH_VARARGS, doc_Qt3DRender_QCamera_tilt},
    {sipName_tiltAboutViewCenter, meth_Qt3DRender_QCamera_tiltAboutViewCenter, METH_VARARGS, doc_Qt3DRender_QCamera_tiltAboutViewCenter},
    {sipName_tiltRotation, meth_Qt3DRender_QCamera_tiltRotation, METH_VARARGS, doc_Qt3DRender_QCamera_tiltRotation},
    {sipName_top, meth_Qt3DRender_QCamera_top, METH_VARARGS, doc_Qt3DRender_QCamera_top},
    {sipName_transform, meth_Qt3DRender_QCamera_transform, METH_VARARGS, doc_Qt3DRender_QCamera_transform},
    {sipName_translate, SIP_MLMETH_CAST(meth_Qt3DRender_QCamera_translate), METH_VARARGS|METH_KEYWORDS, doc_Qt3DRender_QCamera_translate},
    {sipName_translateWorld, SIP_MLMETH_CAST(meth_Qt3DRender_QCamera_translateWorld), METH_VARARGS|METH_KEYWORDS, doc_Qt3DRender_QCamera_translateWorld},
    {sipName_upVector, meth_Qt3DRender_QCamera_upVector, METH_VARARGS, doc_Qt3DRender_QCamera_upVector},
    {sipName_viewAll, meth_Qt3DRender_QCamera_viewAll, METH_VARARGS, doc_Qt3DRender_QCamera_viewAll},
    {sipName_viewCenter, meth_Qt3DRender_QCamera_viewCenter, METH_VARARGS, doc_Qt3DRender_QCamera_viewCenter},
    {sipName_viewEntity, meth_Qt3DRender_QCamera_viewEntity, METH_VARARGS, doc_Qt3DRender_QCamera_viewEntity},
    {sipName_viewMatrix, meth_Qt3DRender_QCamera_viewMatrix, METH_VARARGS, doc_Qt3DRender_QCamera_viewMatrix},
    {sipName_viewSphere, meth_Qt3DRender_QCamera_viewSphere, METH_VARARGS, doc_Qt3DRender_QCamera_viewSphere},
    {sipName_viewVector, meth_Qt3DRender_QCamera_viewVector, METH_VARARGS, doc_Qt3DRender_QCamera_viewVector}
};

static sipEnumMemberDef enummembers_Qt3DRender_QCamera[] = {
    {sipName_DontTranslateViewCenter, static_cast<int>(::Qt3DRender::QCamera::DontTranslateViewCenter), 55},
    {sipName_TranslateViewCenter, static_cast<int>(::Qt3DRender::QCamera::TranslateViewCenter), 55},
};

PyDoc_STRVAR(doc_Qt3DRender_QCamera, "\1QCamera(parent: QNode|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_Qt3DRender_QCamera[] = {
    {"exposureChanged(float)", "\1exposureChanged(self, exposure: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"viewMatrixChanged()", "\1viewMatrixChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"viewVectorChanged(QVector3D)", "\1viewVectorChanged(self, viewVector: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"viewCenterChanged(QVector3D)", "\1viewCenterChanged(self, viewCenter: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"upVectorChanged(QVector3D)", "\1upVectorChanged(self, upVector: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged(QVector3D)", "\1positionChanged(self, position: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"projectionMatrixChanged(QMatrix4x4)", "\1projectionMatrixChanged(self, projectionMatrix: QMatrix4x4)", SIP_NULLPTR, SIP_NULLPTR},
    {"topChanged(float)", "\1topChanged(self, top: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"bottomChanged(float)", "\1bottomChanged(self, bottom: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"rightChanged(float)", "\1rightChanged(self, right: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"leftChanged(float)", "\1leftChanged(self, left: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"aspectRatioChanged(float)", "\1aspectRatioChanged(self, aspectRatio: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"fieldOfViewChanged(float)", "\1fieldOfViewChanged(self, fieldOfView: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"farPlaneChanged(float)", "\1farPlaneChanged(self, farPlane: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"nearPlaneChanged(float)", "\1nearPlaneChanged(self, nearPlane: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"projectionTypeChanged(QCameraLens::ProjectionType)|(Qt3DRender::QCameraLens::ProjectionType)", "\1projectionTypeChanged(self, projectionType: QCameraLens.ProjectionType)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_Qt3DRender_QCamera = {
    &::Qt3DRender::QCamera::staticMetaObject,
    0,
    signals_Qt3DRender_QCamera,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QCamera = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QCamera,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QCamera,
    },
    {
        sipNameNr_QCamera,
        {0, 0, 1},
        49, methods_Qt3DRender_QCamera,
        2, enummembers_Qt3DRender_QCamera,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QCamera,
    -1,
    -1,
    supers_Qt3DRender_QCamera,
    SIP_NULLPTR,
    init_type_Qt3DRender_QCamera,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QCamera,
    SIP_NULLPTR,
    array_Qt3DRender_QCamera,
    SIP_NULLPTR,
    release_Qt3DRender_QCamera,
    cast_Qt3DRender_QCamera,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DRender_QCamera,
    sizeof (::Qt3DRender::QCamera),
};
